@@ -213,7 +213,7 @@ static int syscall_fileopening_out(const char *name, struct Process *process,
                             pathname,
                             mode,
                             path_is_dir(pathname)) != 0)
-            return -1;
+            return -1; /* LCOV_EXCL_LINE */
     }
 
     free(pathname);
@@ -240,14 +240,14 @@ static int syscall_filecreating(const char *name, struct Process *process,
                                 read_path,
                                 FILE_READ | FILE_LINK,
                                 is_dir) != 0)
-                return -1;
+                return -1; /* LCOV_EXCL_LINE */
             free(read_path);
         }
         if(db_add_file_open(process->identifier,
                             written_path,
                             FILE_WRITE | FILE_LINK,
                             is_dir) != 0)
-            return -1;
+            return -1; /* LCOV_EXCL_LINE */
         free(written_path);
     }
     return 0;
@@ -271,14 +271,14 @@ static int syscall_filecreating_at(const char *name, struct Process *process,
                                     read_path,
                                     FILE_READ | FILE_LINK,
                                     is_dir) != 0)
-                    return -1;
+                    return -1; /* LCOV_EXCL_LINE */
                 free(read_path);
             }
             if(db_add_file_open(process->identifier,
                                 written_path,
                                 FILE_WRITE | FILE_LINK,
                                 is_dir) != 0)
-                return -1;
+                return -1; /* LCOV_EXCL_LINE */
             free(written_path);
         }
         else
@@ -302,7 +302,7 @@ static int syscall_filestat(const char *name, struct Process *process,
                             pathname,
                             FILE_STAT | (no_deref?FILE_LINK:0),
                             path_is_dir(pathname)) != 0)
-            return -1;
+            return -1; /* LCOV_EXCL_LINE */
         free(pathname);
     }
     return 0;
@@ -323,7 +323,7 @@ static int syscall_readlink(const char *name, struct Process *process,
                             pathname,
                             FILE_STAT | FILE_LINK,
                             0) != 0)
-            return -1;
+            return -1; /* LCOV_EXCL_LINE */
         free(pathname);
     }
     return 0;
@@ -345,7 +345,7 @@ static int syscall_mkdir(const char *name, struct Process *process,
                             pathname,
                             FILE_WRITE,
                             1) != 0)
-            return -1;
+            return -1; /* LCOV_EXCL_LINE */
         free(pathname);
     }
     return 0;
@@ -368,7 +368,7 @@ static int syscall_chdir(const char *name, struct Process *process,
                             pathname,
                             FILE_WDIR,
                             1) != 0)
-            return -1;
+            return -1; /* LCOV_EXCL_LINE */
     }
     return 0;
 }
@@ -409,7 +409,9 @@ static int record_shebangs(struct Process *process, const char *exec_target)
             struct stat statbuf;
             if(stat(exec_target, &statbuf) != 0)
             {
+                /* LCOV_EXCL_START : stat() shouldn't fail if fopen() above worked */
                 log_error(process->tid, "couldn't stat executed file %s", exec_target);
+                /* LCOV_EXCL_STOP */
             }
             else
             {
@@ -422,7 +424,8 @@ static int record_shebangs(struct Process *process, const char *exec_target)
                                  "Linux will not give the process any "
                                  "privileges from set-uid while it is being "
                                  "traced. This will probably break whatever "
-                                 "you are tracing.");
+                                 "you are tracing. Executable: %s",
+                                 exec_target);
                     }
                     else
                     {
@@ -446,10 +449,12 @@ static int record_shebangs(struct Process *process, const char *exec_target)
                     }
                     if(ret < 0)
                     {
+                        /* LCOV_EXCL_START : Shouldn't ever fail */
                         free(groups);
                         log_critical(process->tid, "getgroups() failed: %s",
                                      strerror(errno));
                         return -1;
+                        /* LCOV_EXCL_STOP */
                     }
 
                     // Check if the gid is one of our groups
@@ -470,7 +475,8 @@ static int record_shebangs(struct Process *process, const char *exec_target)
                                  "Linux will not give the process any "
                                  "privileges from set-gid while it is being "
                                  "traced. This will probably break whatever "
-                                 "you are tracing.");
+                                 "you are tracing. Executable: %s",
+                                 exec_target);
                     }
                     else
                     {
@@ -508,7 +514,7 @@ static int record_shebangs(struct Process *process, const char *exec_target)
                                     pathname,
                                     FILE_READ,
                                     0) != 0)
-                    return -1;
+                    return -1; /* LCOV_EXCL_LINE */
                 free(pathname);
             }
             else
@@ -516,7 +522,7 @@ static int record_shebangs(struct Process *process, const char *exec_target)
                                     start,
                                     FILE_READ,
                                     0) != 0)
-                    return -1;
+                    return -1; /* LCOV_EXCL_LINE */
             exec_target = strcpy(target_buffer, start);
         }
     }
@@ -541,8 +547,7 @@ static int syscall_execve_in(const char *name, struct Process *process,
         log_debug(process->tid, "execve called:\n  binary=%s\n  argv:",
                   execi->binary);
         {
-            /* Note: this conversion is correct and shouldn't need a
-             * cast */
+            /* Note: this conversion is correct and shouldn't need a cast */
             const char *const *v = (const char* const*)execi->argv;
             while(*v)
             {
@@ -592,13 +597,13 @@ int syscall_execve_event(struct Process *process)
             log_critical(process->tid,
                          "execve() completed but call wasn't recorded");
             return -1;
-            /* LCOV_EXCL_END */
+            /* LCOV_EXCL_STOP */
         }
         execi = exec_process->execve_info;
 
         /* The process that called execve() disappears without any trace */
         if(db_add_exit(exec_process->identifier, 0) != 0)
-            return -1;
+            return -1; /* LCOV_EXCL_LINE */
         log_debug(exec_process->tid,
                   "original exec'ing thread removed, tgid: %d",
                   process->tid);
@@ -618,18 +623,18 @@ int syscall_execve_event(struct Process *process)
                    (const char *const*)execi->argv,
                    (const char *const*)execi->envp,
                    process->threadgroup->wd) != 0)
-        return -1;
+        return -1; /* LCOV_EXCL_LINE */
     /* Note that here, the database records that the thread leader called
      * execve, instead of thread exec_process->tid. */
     log_info(process->tid, "successfully exec'd %s", execi->binary);
 
     /* Follow shebangs */
     if(record_shebangs(process, execi->binary) != 0)
-        return -1;
+        return -1; /* LCOV_EXCL_LINE */
 
     if(trace_add_files_from_proc(process->identifier, process->tid,
                                  execi->binary) != 0)
-        return -1;
+        return -1; /* LCOV_EXCL_LINE */
 
     free_execve_info(execi);
     return 0;
@@ -685,7 +690,7 @@ int syscall_fork_event(struct Process *process, unsigned int event)
                      "process created new process %d but we didn't see syscall "
                      "entry", new_tid);
         return -1;
-        /* LCOV_EXCL_END */
+        /* LCOV_EXCL_STOP */
     }
     else if(event == PTRACE_EVENT_CLONE)
         is_thread = process->params[0].u & CLONE_THREAD;
@@ -714,7 +719,7 @@ int syscall_fork_event(struct Process *process, unsigned int event)
                          "just created process that is already running "
                          "(status=%d)", new_process->status);
             return -1;
-            /* LCOV_EXCL_END */
+            /* LCOV_EXCL_STOP */
         }
         new_process->status = PROCSTAT_ATTACHED;
         ptrace(PTRACE_SYSCALL, new_process->tid, NULL, NULL);
@@ -754,7 +759,7 @@ int syscall_fork_event(struct Process *process, unsigned int event)
     if(db_add_process(&new_process->identifier,
                       process->identifier,
                       process->threadgroup->wd, is_thread) != 0)
-        return -1;
+        return -1; /* LCOV_EXCL_LINE */
 
     return 0;
 }
@@ -868,9 +873,11 @@ static int syscall_xxx_at(const char *name, struct Process *process,
             entry = &tbl->entries[real_syscall];
         if(entry == NULL || entry->name == NULL)
         {
+            /* LCOV_EXCL_START : Internal error, our syscall table is broken */
             log_critical(process->tid, "INVALID SYSCALL in *at dispatch: %d",
                          real_syscall);
             return 0;
+            /* LCOV_EXCL_STOP */
         }
         else
         {
@@ -1219,7 +1226,7 @@ int syscall_handle(struct Process *process)
         syscall_type = SYSCALL_X86_64_x32;
         if(logging_level <= 5)
             log_debug(process->tid, "syscall %d (x32) (%s)", syscall, inout);
-        /* LCOV_EXCL_END */
+        /* LCOV_EXCL_STOP */
     }
     else
     {
@@ -1247,7 +1254,9 @@ int syscall_handle(struct Process *process)
         struct syscall_table_entry *entry = NULL;
         struct syscall_table *tbl = &syscall_tables[syscall_type];
         if(syscall < 0 || syscall >= 2000)
+            /* LCOV_EXCL_START : internal error */
             log_error(process->tid, "INVALID SYSCALL %d", syscall);
+            /* LCOV_EXCL_STOP */
         if(entry == NULL && syscall >= 0 && (size_t)syscall < tbl->length)
             entry = &tbl->entries[syscall];
         if(entry != NULL)
@@ -1270,8 +1279,11 @@ int syscall_handle(struct Process *process)
         process->in_syscall = 0;
         if(process->execve_info != NULL)
         {
+            /* LCOV_EXCL_START : internal error */
             log_error(process->tid, "out of syscall with execve_info != NULL");
             return -1;
+            /* LCOV_EXCL_STOP */
+
         }
         process->current_syscall = -1;
     }
