@@ -1,4 +1,4 @@
-# Copyright (C) 2014-2017 New York University
+# Copyright (C) 2014 New York University
 # This file is part of ReproZip which is released under the Revised BSD License
 # See file LICENSE for full license details.
 
@@ -26,6 +26,7 @@ import copy
 from datetime import datetime
 from distutils.version import LooseVersion
 import functools
+import gzip
 import logging
 import logging.handlers
 import os
@@ -36,8 +37,7 @@ import usagestats
 import yaml
 
 from .utils import iteritems, itervalues, unicode_, stderr, UniqueNames, \
-    escape, CommonEqualityMixin, optional_return_type, isodatetime, hsize, \
-    join_root, copyfile
+    escape, optional_return_type, isodatetime, hsize, join_root, copyfile
 
 
 logger = logging.getLogger(__name__.split('.', 1)[0])
@@ -50,7 +50,7 @@ FILE_STAT = 0x08
 FILE_LINK = 0x10
 
 
-class File(CommonEqualityMixin):
+class File(object):
     """A file, used at some point during the experiment.
     """
     comment = None
@@ -63,11 +63,14 @@ class File(CommonEqualityMixin):
         return (isinstance(other, File) and
                 self.path == other.path)
 
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
     def __hash__(self):
         return hash(self.path)
 
 
-class Package(CommonEqualityMixin):
+class Package(object):
     """A distribution package, containing a set of files.
     """
     def __init__(self, name, version, files=None, packfiles=True, size=None):
@@ -77,6 +80,14 @@ class Package(CommonEqualityMixin):
         self.packfiles = packfiles
         self.size = size
 
+    def __eq__(self, other):
+        return (isinstance(other, Package) and
+                self.name == other.name and
+                self.version == other.version)
+
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
     def add_file(self, file_):
         self.files.append(file_)
 
@@ -166,13 +177,33 @@ class RPZPack(object):
 
         It is up to the caller to remove that file once done.
         """
-        member = copy.copy(self.tar.getmember('METADATA/config.yml'))
+        self._extract_file(self.tar.getmember('METADATA/config.yml'),
+                           target)
+
+    def _extract_file(self, member, target):
+        member = copy.copy(member)
         member.name = str(target.components[-1])
         self.tar.extract(member,
                          path=str(Path.cwd() / target.parent))
         target.chmod(0o644)
         assert target.is_file()
 
+    def _extract_file_gz(self, member, target):
+        f_in = self.tar.extractfile(member)
+        f_in_gz = gzip.open(f_in)
+        f_out = target.open('wb')
+        try:
+            chunk = f_in_gz.read(4096)
+            while len(chunk) == 4096:
+                f_out.write(chunk)
+                chunk = f_in_gz.read(4096)
+            if chunk:
+                f_out.write(chunk)
+        finally:
+            f_out.close()
+            f_in_gz.close()
+            f_in.close()
+
     @contextlib.contextmanager
     def with_config(self):
         """Context manager that extracts the config to  a temporary file.
@@ -191,19 +222,19 @@ class RPZPack(object):
         target = Path(target)
         if self.version == 1:
             member = self.tar.getmember('METADATA/trace.sqlite3')
+            self._extract_file(member, target)
         elif self.version == 2:
             try:
                 member = self.tar.getmember('METADATA/trace.sqlite3.gz')
             except KeyError:
-                member = self.tar.getmember('METADATA/trace.sqlite3')
+                pass
+            else:
+                self._extract_file_gz(member, target)
+                return
+            member = self.tar.getmember('METADATA/trace.sqlite3')
+            self._extract_file(member, target)
         else:
             assert False
-        member = copy.copy(member)
-        member.name = str(target.components[-1])
-        self.tar.extract(member,
-                         path=str(Path.cwd() / target.parent))
-        target.chmod(0o644)
-        assert target.is_file()
 
     @contextlib.contextmanager
     def with_trace(self):
@@ -343,6 +374,16 @@ def load_iofiles(config, runs):
         path = PosixPath(f['path'])
         readers = sorted(f.get('read_by_runs', []))
         writers = sorted(f.get('written_by_runs', []))
+        if (
+            not isinstance(readers, (tuple, list))
+            or not all(isinstance(e, int) for e in readers)
+        ):
+            raise InvalidConfig("read_by_runs should be a list of integers")
+        if (
+            not isinstance(writers, (tuple, list))
+            or not all(isinstance(e, int) for e in writers)
+        ):
+            raise InvalidConfig("written_by_runs should be a list of integers")
         if name in files:
             if files[name].path != path:
                 old_name, name = name, uniquenames(name)
@@ -596,34 +637,36 @@ def setup_logging(tag, verbosity):
     handler.setFormatter(formatter)
 
     # Set up logger
-    logger = logging.root
-    logger.setLevel(min_level)
-    logger.addHandler(handler)
+    rootlogger = logging.root
+    rootlogger.setLevel(min_level)
+    rootlogger.addHandler(handler)
 
     # File logger
-    dotrpz = Path('~/.reprozip').expand_user()
-    try:
-        if not dotrpz.is_dir():
-            dotrpz.mkdir()
-        filehandler = logging.handlers.RotatingFileHandler(str(dotrpz / 'log'),
-                                                           mode='a',
-                                                           delay=False,
-                                                           maxBytes=400000,
-                                                           backupCount=5)
-    except (IOError, OSError):
-        logger.warning("Couldn't create log file %s", dotrpz / 'log')
-    else:
-        filehandler.setFormatter(formatter)
-        filehandler.setLevel(file_level)
-        logger.addHandler(filehandler)
+    if os.environ.get('REPROZIP_NO_LOGFILE', '').lower() in ('', 'false',
+                                                             '0', 'off'):
+        dotrpz = Path('~/.reprozip').expand_user()
+        try:
+            if not dotrpz.is_dir():
+                dotrpz.mkdir()
+            filehandler = logging.handlers.RotatingFileHandler(
+                str(dotrpz / 'log'), mode='a',
+                delay=False, maxBytes=400000, backupCount=5)
+        except (IOError, OSError):
+            logger.warning("Couldn't create log file %s", dotrpz / 'log')
+        else:
+            filehandler.setFormatter(formatter)
+            filehandler.setLevel(file_level)
+            rootlogger.addHandler(filehandler)
 
-        filehandler.emit(logging.root.makeRecord(
-            __name__.split('.', 1)[0],
-            logging.INFO,
-            "(log start)", 0,
-            "Log opened %s %s",
-            (datetime.now().strftime("%Y-%m-%d"), sys.argv),
-            None))
+            filehandler.emit(logging.root.makeRecord(
+                __name__.split('.', 1)[0],
+                logging.INFO,
+                "(log start)", 0,
+                "Log opened %s %s",
+                (datetime.now().strftime("%Y-%m-%d"), sys.argv),
+                None))
+
+    logging.getLogger('urllib3').setLevel(logging.INFO)
 
 
 _usage_report = None
@@ -740,4 +783,24 @@ YIKRjGU7Of3CycOCbaT50VZHhEd5GS2Lvg41ngxtsE8JKnvPuim92dnCutD0beV+
 DCfXxuMMg3wo5pbqG+MvTdECaLwt14zWU259z8JX0BoeVG32kHlt2eUpm5PCfxqc
 dYuwZmAXksp0T0cWo0DnjJKRGQ==
 -----END CERTIFICATE-----
+-----BEGIN CERTIFICATE-----
+MIIDRDCCAiygAwIBAgIUXaa8P7qR4c0P51hCDIqj4GUbG/owDQYJKoZIhvcNAQEL
+BQAwEzERMA8GA1UEAwwIUmVwcm9aaXAwIBcNMjEwNDI5MjEwNTUzWhgPMjEyMTA0
+MjkyMTA1NTNaMBMxETAPBgNVBAMMCFJlcHJvWmlwMIIBIjANBgkqhkiG9w0BAQEF
+AAOCAQ8AMIIBCgKCAQEA3udPriZ8kziQE+OyLVozJFDSZTe8RLlpFsu/ZQjSnIh1
+TsENMMu1lwv0GVEpT/EbtD5ORtZzwYQ7Vuh+IO4TQDhA5KvyJD2gZW8hE4txkkQd
+yI5vSj0iiViA80tKB7FSDLsvz9iiDxShYHJI947gswbaLmampHIXD/Rjjs7+hmL5
+RRS5NL8vCp2/2QVj5wnJupa5O2l2T1M6S/SyFcAgBMM/FhDsaA/yf4NPcOG6gFuO
+b5mYz2ERSf4v9mRL+G3r6YULYGZWS5ThY0QoZ0lYt2nlthzwfftazrJ9+yfYBkoJ
+K6Ug8UGtyOb5m3mK00c4wS7/wzuGgLMszkE0nE9SfwIDAQABo4GNMIGKMB0GA1Ud
+DgQWBBSqrIPVnO5vkHj9ImGvOr38r4rcNjBOBgNVHSMERzBFgBSqrIPVnO5vkHj9
+ImGvOr38r4rcNqEXpBUwEzERMA8GA1UEAwwIUmVwcm9aaXCCFF2mvD+6keHND+dY
+QgyKo+BlGxv6MAwGA1UdEwQFMAMBAf8wCwYDVR0PBAQDAgEGMA0GCSqGSIb3DQEB
+CwUAA4IBAQC2g8yX1c5JutH/qAKUVvqSwP2KBm3IyOjdbN7cvnwn0gMkwEj88j7p
+dKhfO0Kfp/N4iKj1YK7PBXfrdlYhxINSbfPSVS3A9XWi8pJwiwgBfjrrACRMhBsv
+HAQPnkXnaEJrQm//k8s4etT25JYaPgXS8t+dgVS0iqonYlpCB1XkE0gw1kLNCW5F
+1SimUehJ5bZrJYGgo6kp44F12kPMzNHvk50Sf2p3nm2d9/BNbbJQxUBKt9n+i6Ir
+xGGDWfg5F+BLKURWkoGBnnLPqkRxlkaGvk6QpIAfD1h99fTyuWUno3+NoQ7hS952
+yWbmqwbavTIyG+D+kfhbGFEdRxLF5BeK
+-----END CERTIFICATE-----
 '''
